# Validation Messages

- [Info (I)](INFO.md) - Informational messages
- [Errors (E)](ERRORS.md) - Error messages
- [Warnings (W)](WARNINGS.md) - Warning messages
- [Rules](RULES.md) - Validation rules and their meanings
